@@ -7,7 +7,7 @@ use Carp;
 use RRDs;
 use Log::Log4perl qw(:easy);
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
    # Define the mandatory and optional parameters for every method.
 our $OPTIONS = {
@@ -47,7 +47,9 @@ our $OPTIONS = {
                     draw      => {
                       mandatory => [qw()],
                       optional  => [qw(file dsname cfunc thickness 
-                                       type color legend name cdef vdef)],
+                                       type color legend name cdef vdef
+                                       stack
+                                      )],
                     },
                     color     => {
                       mandatory => [qw()],
@@ -921,6 +923,7 @@ sub process_draw {
 
         my $draw_attributes = ":$p->{name}#$p->{color}";
         $draw_attributes .= ":$p->{legend}" if length $p->{legend};
+        $draw_attributes .= ":STACK" if exists $p->{stack};
 
         if($p->{type} eq "hidden") {
             # Invisible graph
@@ -929,7 +932,8 @@ sub process_draw {
         } elsif($p->{type} eq "area") {
             push @$options, "AREA$draw_attributes";
         } elsif($p->{type} eq "stack") {
-            push @$options, "STACK$draw_attributes";
+              # modified for backwards compatibility
+            push @$options, "AREA$draw_attributes:STACK";
         } else {
             die "Invalid graph type: $p->{type}";
         }
@@ -1283,10 +1287,13 @@ one to draw:
     );
 
 If C<draw> doesn't define a C<type>, it defaults to C<"line">. If
-you don't want to define a type (because the graph shouldn't drawn), 
+you don't want to define a type (because the graph shouldn't be drawn), 
 use C<type =E<gt> "hidden">. Other
-values are C<"area"> for solid colored areas and C<"stack"> for 
-graphical values stacked on top of each other.
+values are C<"area"> for solid colored areas. The C<"stack"> type
+(for graphical values stacked on top of each other)
+has been deprecated sind rrdtool-1.2, but RRDTool::OO still supports it
+by transforming it into an 'area' type with a 'stack' option.
+
 And you can certainly have more than one graph in the picture:
 
     $rrd->graph(
@@ -1298,7 +1305,8 @@ And you can certainly have more than one graph in the picture:
         dsname    => "load",
         cfunc     => 'MAX'},
       draw        => {
-        type      => 'stack',
+        type      => 'area',
+        stack     => 1,
         color     => '00FF00', # a green area stacked on top of the red one 
         dsname    => "load",
         cfunc     => 'AVERAGE'},
@@ -1316,7 +1324,8 @@ which file you want to draw the data from, using C<draw>:
       },
       draw        => {
         file      => "file2.rrd",
-        type      => 'stack',
+        type      => 'area',
+        stack     => 1,
         color     => '00FF00', # a green area stacked on top of the red one 
         dsname    => "load",
         legend    => "Second Source",
